Control messages for node and engine management.
This module defines messages used to control node lifecycle and modify pipeline graphs at runtime:
NodeControlMessage: Messages sent to individual nodes to update parameters or control executionEngineControlMessage: Messages sent to the engine to modify the pipeline graphConnectionMode: How a connection handles backpressure
Enums
- Connection
Mode - Specifies how a connection handles backpressure from slow consumers.
- Engine
Control Message - A message sent to the central Engine actor to modify the pipeline graph itself.
- Node
Control Message - A message sent to a specific, running node to tune its parameters or control its lifecycle.