pub enum OutputRouting {
Direct(HashMap<String, Sender<Packet>>),
Routed(Sender<RoutedPacketMessage>),
}Expand description
An enum representing the two ways a node’s output can be routed.
Variants
Direct(HashMap<String, Sender<Packet>>)
Packets are sent directly to the input channels of downstream nodes.
Routed(Sender<RoutedPacketMessage>)
Packets are sent to a central engine actor for routing.
Uses Arc