pub struct OutputSender { /* private fields */ }Expand description
A handle given to a node to send its output packets.
Implementations
Sourceimpl OutputSender
impl OutputSender
Sourcepub fn new(node_name: String, routing: OutputRouting) -> Self
pub fn new(node_name: String, routing: OutputRouting) -> Self
Creates a new OutputSender.
Note: The node_name String is converted to Arc
Sourcepub async fn send(
&mut self,
pin_name: &str,
packet: Packet,
) -> Result<(), OutputSendError>
pub async fn send( &mut self, pin_name: &str, packet: Packet, ) -> Result<(), OutputSendError>
Sends a packet from a specific output pin of this node.
Returns Ok(()) if sent successfully.
Nodes should stop processing when this returns an error, as it indicates either a programming mistake (unknown pin) or that the pipeline is shutting down.
Errors
Returns OutputSendError::PinNotFound if the pin doesn’t exist, or
OutputSendError::ChannelClosed if the receiving channel is closed.