pub enum PinUpdate {
NoChange,
Updated {
inputs: Vec<InputPin>,
outputs: Vec<OutputPin>,
},
}Expand description
Result of node initialization.
Nodes can update their pin definitions during initialization if they need to discover types or counts from external sources.
Variants
NoChange
Pins are unchanged from the initial definition
Updated
Pins have been updated (e.g., discovered from external source)