ResourceKey

Struct ResourceKey 

pub struct ResourceKey {
    pub plugin_kind: String,
    pub params_hash: String,
}
A unique key identifying a resource based on plugin kind and parameters.

Fields

plugin_kind: String

The plugin kind (e.g., “plugin::native::kokoro”, “plugin::native::whisper”)

params_hash: String

Hash of canonicalized parameters that affect resource creation

Implementations

Source

impl ResourceKey

pub fn new( plugin_kind: impl Into<String>, params_hash: impl Into<String>, ) -> Self

Create a new resource key from plugin kind and params hash.